This function implements the BCA1SG algorithm on the semiparametric random-effects inverse Gaussian process model for degradation data to solve the ML estimates of the model parameters.
BCA1SG_degradation(input_data, initial_delta, initial_r, initial_Lambda = function(x){x},
threshold = 1e-05, max_iter = 5000, max_stepsize = 1e+05, xi = 0.3, contraction = 0.5)An object of class data.frame. The structure of the data frame must be {subject ID, time of measurement, measurement}.. This data frame cannot contain missing values. See the dataset "liner" for an example.
The initial value of the shape parameter of the gamma distributed scale parameter in the random-effects inverse Gaussian process. See Wang and Xu (2010) for details.
The initial value of the rate parameter of the gamma distributed scale parameter in the random-effects inverse Gaussian process. See Wang and Xu (2010) for details.
An R function which serves as the initial value of the baseline mean function.
Convergence threshold. The algorithm is terminated when the infinity norm of the difference between successive iterates is less than the convergence threshold.
Maximum number of iterations allowed.
Maximum stepsize allowed.
The xi parameter in the inexact backtracking line search algorithm. See Wang et al. (2020) for details.
The contraction parameter in the inexact backtracking line search algorithm. See Wang et al. (2020) for details.
The set of distinct observation time points.
The estimated baseline mean function at the set of distinct observation time points.
The estimated shape parameter of the gamma distributed scale parameter in the random-effects inverse Gaussian process.
The estimated rate parameter of the gamma distributed scale parameter in the random-effects inverse Gaussian process.
The number of iterations.
The computational time in seconds.
Details about the BCA1SG algorithm can be found in Wang et al. (2020), and the details concerning the semiparametric random-effects inverse Gaussian process model can be found in Section 3 of Wang and Xu (2010).
Wang Y., Ye, Z.-S., and Cao, H.(2020). On Computation of Semi-Parametric Maximum Likelihood Estimators with Shape Constraints. Submitted.
Wang X. and Xu, D.(2010). An Inverse Gaussian Process Model for Degradation Data. Technometrics, 52(2), 188-197.
# NOT RUN {
data(liner)
res<-BCA1SG_degradation(liner, initial_delta = 1, initial_r = 1, threshold = 5e-2)
res$est_delta
res$est_r
res$iteration
res$timecost
plot(res$distinct_time,res$est_Lambda,type="s",lwd=3,xlab="time",ylab="Baseline mean function")
# }
Run the code above in your browser using DataLab