Learn R Programming

BCA1SG (version 0.1.0)

adapt_duser: A data set adapted from the data set "duser" in the package "FHtest"

Description

Data set of 763 drug users in Badalona (Spain). The data come from the detoxification unit of Hospital Universitari Germans Trias i Pujol in Badalona, Spain. See G<U+00F3>mez et al. (2000) for details.

Usage

data("adapt_duser")

Arguments

Format

A data frame with 763 observations on the following 4 variables.

left

left endpoint of time to HIV-infection.

right

right endpoint of time to HIV-infectio.n

zgen

gender (0: male; 1: female).

age

patient's age.

References

G<U+00F3>mez, G., Calle, M. L., Egea, J. M., and Muga, R.(2000). Risk of HIV infection as a function of the duration of intravenous drug use: A non-parametric Bayesian approach. Statistics in Medicine 19(19), 2641<U+2013>2656.