Learn R Programming

BCA1SG (version 0.1.0)

adapt_skiTum: A data set adapted from the data set "skiTum" in the package "spef"

Description

A data frame containing the recurrence of skin tumors. See Chiou et al. (2017) for details.

Usage

data("adapt_skiTum")

Arguments

Format

A data frame with 894 observations on the following 7 variables.

id

patient id (repeated for each recurrence).

time

observation time.

count

cumulative number of tumors till the current observation time.

age

patient's age at enrollment; age = 1 if greater than 65, age = 0 otherwise.

male

gender; male = 1, female = 0.

dfmo

treatment (DFMO) group = 1; placebo = 0.

priorTumor

number of prior tumor from diagnosis to randomization.

References

Chiou S. H., Xu G., Yan J., and Huang C.(2018). Semiparametric Estimation of the Accelerated Mean Model with Panel Count Data under Informative Examination Times. Biometrics, 74(3), 944-953.