Learn R Programming

BCA1SG (version 0.1.0)

liner: The marine engine cylinder liner data from Giorgio et al. (2012)

Description

The degradation data measured on 32 marine engine cylinder liners from January 1999 to August 2006. See Giorgio et al. (2012) for details.

Usage

data("liner")

Arguments

Format

A data frame with 64 observations on the following 3 variables.

ID

liner ID.

Timepoints

the time of measurement (in years).

Measurements

the measurement (in mm).

References

Giorgio M., Guida M., and Pulcini G.(2012). A State-Dependent Wear Model with an Application to Marine Engine Cylinder Liners. Technometrics, 52(2), 172-187.