Data set of 763 drug users in Badalona (Spain). The data come from the detoxification unit of Hospital Universitari Germans Trias i Pujol in Badalona, Spain. See G<U+00F3>mez et al. (2000) for details.
data("adapt_duser")A data frame with 763 observations on the following 4 variables.
leftleft endpoint of time to HIV-infection.
rightright endpoint of time to HIV-infectio.n
zgengender (0: male; 1: female).
agepatient's age.
G<U+00F3>mez, G., Calle, M. L., Egea, J. M., and Muga, R.(2000). Risk of HIV infection as a function of the duration of intravenous drug use: A non-parametric Bayesian approach. Statistics in Medicine 19(19), 2641<U+2013>2656.